"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@angular-devkit/core");
const parse_name_1 = require("../utility/parse-name");
const schematics_1 = require("@angular-devkit/schematics");
const find_module_1 = require("../utility/find-module");
const ast_utils_1 = require("../utility/ast-utils");
const change_1 = require("../utility/change");
const ts = require("typescript");
const core = require("@angular-devkit/core");
// You don't have to export the function as default. You can also have more than one rule factory
// per file.
function createExample(_options) {
    _options.path = 'src/app/pages/';
    const parsedPath = parse_name_1.parseName(_options.path, _options.name);
    _options.name = core_1.strings.dasherize(parsedPath.name);
    _options.container = core_1.strings.dasherize(parsedPath.name) + '-container';
    const templateSource = schematics_1.apply(schematics_1.url('./files'), [
        schematics_1.template(Object.assign({}, core_1.strings, { 'if-flat': (s) => _options.flat ? '' : s }, _options)),
        schematics_1.move(parsedPath.path),
    ]);
    return schematics_1.chain([
        schematics_1.branchAndMerge(schematics_1.chain([
            addDeclarationToNgModule(_options),
            schematics_1.mergeWith(templateSource),
        ])),
    ]);
}
exports.createExample = createExample;
function readIntoSourceFile(host, modulePath) {
    const text = host.read(modulePath);
    if (text === null) {
        throw new schematics_1.SchematicsException(`File ${modulePath} does not exist.`);
    }
    const sourceText = text.toString('utf-8');
    return ts.createSourceFile(modulePath, sourceText, ts.ScriptTarget.Latest, true);
}
function addDeclarationToNgModule(options) {
    return (host) => {
        if (options.skipImport) {
            return host;
        }
        const modulePath = core.normalize('/' + 'src/app/app.module.ts');
        const source = readIntoSourceFile(host, modulePath);
        const componentContainerPath = `/${options.path}/`
            + core_1.strings.dasherize(options.name) + '-container/'
            + core_1.strings.dasherize(options.name)
            + '-container.component';
        const relativePathContainer = find_module_1.buildRelativePath(modulePath, componentContainerPath);
        const classifiedNameContainer = core_1.strings.classify(`${options.name}ContainerComponent`);
        const declarationChangesForContainer = ast_utils_1.addDeclarationToModule(source, modulePath, classifiedNameContainer, relativePathContainer);
        const componentExamplePath = `/${options.path}/`
            + core_1.strings.dasherize(options.name) + '-container/'
            + core_1.strings.dasherize(options.name) + '-example/'
            + core_1.strings.dasherize(options.name) + '-example.component';
        const relativePathExample = find_module_1.buildRelativePath(modulePath, componentExamplePath) + '';
        const classifiedNameExample = core_1.strings.classify(`${options.name}ExampleComponent`);
        const declarationChangesForExample = ast_utils_1.addDeclarationToModule(source, modulePath, classifiedNameExample, relativePathExample);
        const declarationRecorder = host.beginUpdate(modulePath);
        for (const change of declarationChangesForContainer) {
            if (change instanceof change_1.InsertChange) {
                declarationRecorder.insertLeft(change.pos, change.toAdd);
            }
        }
        for (const change of declarationChangesForExample) {
            if (change instanceof change_1.InsertChange) {
                declarationRecorder.insertLeft(change.pos, change.toAdd);
            }
        }
        host.commitUpdate(declarationRecorder);
        return host;
    };
}
function buildSelector(options, projectPrefix) {
    let selector = core_1.strings.dasherize(options.name);
    if (options.prefix) {
        selector = `${options.prefix}-${selector}`;
    }
    else if (options.prefix === undefined && projectPrefix) {
        selector = `${projectPrefix}-${selector}`;
    }
    return selector;
}
//# sourceMappingURL=index.js.map